@@ -1,20 +1,13 @@
 use std::{iter, mem};
 use swc_common::{chain, util::move_map::MoveMap, Mark, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::helper;
-use swc_ecma_transforms_base::helper_expr;
-use swc_ecma_transforms_base::perf::Check;
+use swc_ecma_transforms_base::{helper, helper_expr, perf::Check};
 use swc_ecma_transforms_macros::fast_path;
-use swc_ecma_utils::alias_ident_for;
-use swc_ecma_utils::alias_if_required;
-use swc_ecma_utils::is_literal;
-use swc_ecma_utils::private_ident;
-use swc_ecma_utils::quote_ident;
-use swc_ecma_utils::var::VarCollector;
-use swc_ecma_utils::ExprFactory;
-use swc_ecma_utils::StmtLike;
-use swc_ecma_visit::noop_visit_type;
-use swc_ecma_visit::{noop_fold_type, Fold, FoldWith, Node, Visit, VisitWith};
+use swc_ecma_utils::{
+    alias_ident_for, alias_if_required, is_literal, private_ident, quote_ident, var::VarCollector,
+    ExprFactory, StmtLike,
+};
+use swc_ecma_visit::{noop_fold_type, noop_visit_type, Fold, FoldWith, Node, Visit, VisitWith};
 
 /// `@babel/plugin-proposal-object-rest-spread`
 pub fn object_rest_spread() -> impl Fold {
