@@ -1,7 +1,6 @@
 use swc_common::DUMMY_SP;
 use swc_ecma_ast::*;
-use swc_ecma_utils::IdentExt;
-use swc_ecma_utils::IsDirective;
+use swc_ecma_utils::{IdentExt, IsDirective};
 use swc_ecma_visit::{noop_fold_type, Fold};
 
 pub fn export_namespace_from() -> impl Fold {
