@@ -5,7 +5,7 @@ use swc_ecma_transforms_compat::{
     es2015::{block_scoping, for_of::for_of},
     es2017::async_to_generator,
 };
-use swc_ecma_transforms_testing::{test, test_exec, Tester};
+use swc_ecma_transforms_testing::{compare_stdout, test, test_exec, Tester};
 
 test!(
     ::swc_ecma_parser::Syntax::default(),
@@ -528,19 +528,19 @@ test!(
                                 [
                                     3
                                 ]
-                            ].map(_asyncToGenerator(regeneratorRuntime.mark(function _callee1(param) {
+                            ].map(_asyncToGenerator(regeneratorRuntime.mark(function _callee(param) {
                                 var _param = _slicedToArray(param, 1), a = _param[0];
-                                return regeneratorRuntime.wrap(function _callee$1(_ctx1) {
-                                    while(1)switch(_ctx1.prev = _ctx1.next){
+                                return regeneratorRuntime.wrap(function _callee$(_ctx) {
+                                    while(1)switch(_ctx.prev = _ctx.next){
                                         case 0:
-                                            return _ctx1.abrupt("return", Promise.resolve().then(function() {
+                                            return _ctx.abrupt("return", Promise.resolve().then(function() {
                                                 return a * 2;
                                             }));
                                         case 1:
                                         case "end":
-                                            return _ctx1.stop();
+                                            return _ctx.stop();
                                     }
-                                }, _callee1);
+                                }, _callee);
                             }))));
                         case 2:
                         case "end":
@@ -778,7 +778,7 @@ test!(
         "
 );
 
-test!(
+compare_stdout!(
     ::swc_ecma_parser::Syntax::default(),
     |Tester { comments, .. }| {
         let mark = Mark::fresh(Mark::root());
@@ -792,22 +792,14 @@ test!(
     },
     arguments_arrow,
     "
-        function test() {
-            for (var i = 0; i < arguments.length; i++) {
-              console.log((() => arguments[i])());
-            }
+    function test() {
+        for (var i = 0; i < arguments.length; i++) {
+            console.log((() => arguments[i])());
         }
-        ",
+    }
+
+    test(1, 2, 3);
     "
-        function test() {
-            var _this = this, _arguments = arguments, _loop = function(i) {
-                console.log((function(_arguments1) {
-                    return _arguments1[i];
-                }).bind(_this, _arguments)());
-            };
-            for(var i = 0; i < arguments.length; i++)_loop(i);
-        }
-        "
 );
 
 test!(
